flutter_secure_dotenv_generator library

Code generator for flutter_secure_dotenv.

Reads .env files at build time, encrypts the values with AES-CBC, and emits a part file containing the encrypted data.

Functions

flutterSecureDotEnvAnnotation(BuilderOptions options) → Builder
Creates a SharedPartBuilder for generating secure dotenv annotations.